%% --------------------------------------------------- %%
%% AiMT Class for LaTeX files         31 December 2022 %%
%% --------------------------------------------------- %%

\NeedsTeXFormat{LaTeX2e}[1995/12/01]
\ProvidesClass{aimt}%[2022/12/31 AiMT article]

\RequirePackage{lineno}
\newcommand{\cerna}{\normalcolor}
\RequirePackage{xcolor}
%\DeclareOption{review}{\renewcommand{\cerna}{\color{white}}}
%\RequirePackage{draftwatermark}
\newcommand{\revfoot}{ }
\DeclareOption{preprint}{%
\renewcommand{\revfoot}{{\large \phantom{a}\hfill PREPRINT \hfill \today \hfill\phantom{a}}}%
}
\DeclareOption{numbers}{\linenumbers}
\DeclareOption{twocolumn}{\OptionNotUsed}
\DeclareOption{11pt}{\OptionNotUsed}
\DeclareOption{12pt}{\OptionNotUsed}

\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions\relax

\LoadClass[b5paper,twoside]{article}

%% packages used
\RequirePackage[english]{babel}
\RequirePackage[utf8]{inputenc}
\RequirePackage{times} %fourier
\RequirePackage{mathptmx}
\RequirePackage{color}
\RequirePackage{graphicx}
\RequirePackage{amsmath,amssymb,amsfonts,amsthm}
\RequirePackage{url}
\urlstyle{same}

% \RequirePackage[hang,flushmargin]{footmisc}

%% page style
\RequirePackage[b5paper, inner=2.7cm, outer=2.3cm, top=1.6cm, bottom=2.5cm,%
  marginparwidth=0pt, marginpar=0pt,%
  headsep=0.54cm, footskip=1.25cm]{geometry}
\setlength\parskip{0pt}
\setlength\parindent{0.75cm}
\hbadness=7000
% allow loose lines rather than overfull lines
\vbadness=5000
% disallow widows and orphans
\widowpenalty=10000
\clubpenalty=10000
% allow breaking the page in the middle of a paragraph
\interlinepenalty=0
% disallow breaking the page after a hyphenated line
\brokenpenalty=10000
\emergencystretch=1em


%% head and foot
\RequirePackage{lastpage}
\RequirePackage{fancyhdr}
\pagestyle{fancy}
\addtolength{\headheight}{2.14\baselineskip}
\fancyhf{}
\newcommand{\odsazeni}{\vrule height6mm width0mm depth6mm}
\newcommand{\licha}{\phantom{2}\odsazeni \hfill Advances in Military Technology, \rok, vol. \tom, no. \num, pp. \startpage--\pageref{LastPage} \hfill \thepage}
\newcommand{\suda}{\thepage \hfill DOI 10.3849/aimt.\doinum \hfill \odsazeni\phantom{2}}
\fancyhead[CO]{\licha}
\fancyhead[CE]{\suda}
% review foot
\fancyfoot[C]{\revfoot}


%% first page
\newcommand\hlavicka{%
	\vspace*{-1.4cm}
  \centerline{
  \hfill
  \begin{minipage}[c]{2.35cm}
  \includegraphics[width=2.35cm]{./images/znak_aimt}
  \end{minipage}
  \hfill
  \begin{minipage}[c]{6.5cm}
  \begin{center}
  {\large Advances in Military Technology} \\
  Vol. \tom, No. \num, \rok, pp. \startpage--\pageref{LastPage} \\
  ISSN 1802-2308, eISSN 2533-4123 \\
  DOI 10.3849/aimt.\doinum
  \end{center}
  \end{minipage}
  \hfill
  \begin{minipage}[c]{1.9cm}
  \includegraphics[width=1.9cm]{./images/znak_uo}
  \end{minipage}
  \hfill
  }
	\vspace*{0.5mm}
  \noindent\hrulefill
}
%
\renewcommand{\footnotesize}{\fontsize{9}{11}\selectfont\itshape}
\setlength{\footnotesep}{1pc}
%\renewcommand\@makefntext[1]{\leftskip=2em\hskip-2em\@makefnmark#1}
\renewcommand\maketitle{%
\par
\begingroup
  \renewcommand\thefootnote{\@fnsymbol\c@footnote}%
  \def\@makefnmark{\rlap{\@textsuperscript{\normalfont\@thefnmark}}}%
%  \long\def\@makefntext##1{\parindent 1em\noindent
%          \hb@xt@0.4em{%      Odsazeni poznamky pod carou 3/1/2023
%              \hss\@textsuperscript{\normalfont\@thefnmark}} \cerna ##1}%
  \long\def\@makefntext##1{\leftskip=0.9em\hskip-0.8em
          \hb@xt@0.45em{%      Odsazeni poznamky pod carou 2023-02-07
              \hss\@textsuperscript{\normalfont\@thefnmark}} \cerna ##1}%
  \global\@topnum\z@   % Prevents figures from going at top of page.
  \@maketitle
  \thispagestyle{empty}\@thanks
\endgroup
\setcounter{footnote}{0}%
\global\let\thanks\relax
\global\let\maketitle\relax
\global\let\@maketitle\relax
\global\let\@thanks\@empty
\global\let\@author\@empty
\global\let\@date\@empty
\global\let\@title\@empty
\global\let\title\relax
\global\let\author\relax
\global\let\date\relax
\global\let\and\relax
}
%
\RequirePackage{authblk}
\renewcommand\Affilfont{\fontsize{9}{11}\selectfont\itshape}
\renewcommand\Authsep{, }
\renewcommand\Authand{ and }
\renewcommand\Authands{ and }
\newcommand{\prijeti}{%
  The manuscript was received on \rece\ and was accepted \linebreak
	after revision for publication as \type\ on \acce.
}
%
\def\@maketitle{%
  \thispagestyle{empty}
  \hlavicka
	\vspace{5mm}
  \begin{center}%
  \let \footnote \thanks
  {\fontsize{16}{20}\selectfont \@title \par}%
  \vskip 1.25em%
  {\fontsize{12}{14}\selectfont \cerna \@author \par}%
  \vskip 1.5em%
  {\fontsize{9}{11}\selectfont \cerna \prijeti \par}%
	\vskip 1.4em%
  \end{center}%
}
%
\newcommand{\Abstract}[1]{
  \noindent\textbf{Abstract:}\\[1.8mm]%
	{\fontsize{10}{12}\selectfont\itshape{#1}}\\[0.4mm]%
}
\newcommand{\Keywords}[1]{
  \noindent\textbf{Keywords:}\\[1.8mm]
	{\fontsize{10}{12}\selectfont\itshape{#1}}%
}


%% sections
\setcounter{secnumdepth}{3}
\renewcommand\thesection{\@arabic\c@section}
\renewcommand\thesubsection{\thesection.\@arabic\c@subsection\hspace{-2mm}}
\renewcommand\thesubsubsection{\hspace{-4.1mm}}
%
\renewcommand\section{%
  \@startsection{section}{1}{\z@}%
     {-3.5ex \@plus -1ex \@minus -.2ex}%
     {0.7ex \@plus .2ex}%
     {\normalfont\large\bfseries}%
}
\renewcommand\subsection{%
  \@startsection{subsection}{2}{\z@}%
    {-2.8ex\@plus -1ex \@minus -.2ex}%
    {1.4ex \@plus .2ex}%
    {\normalfont\bfseries\itshape}%
}
\renewcommand\subsubsection{%
  \@startsection{subsubsection}{3}{\z@}%
    {-1ex\@plus -0.2ex \@minus -.2ex}%
    {0.01ex \@plus 0ex}%
    {\normalfont\bfseries}%
}


%% unordered lists
\def\itemargs{%
   \leftmargini0.5cm%
   \leftmarginii0cm%
   \ifnum\@enumdepth=3\topsep0pt\else\ifnum\@enumdepth=2\topsep0pt\else\topsep 1pt\fi\fi%
   \partopsep     \z@%
   \itemsep       \z@%
   \parsep        \z@%
   \labelsep      0.84em%
   \rightmargin   \z@%
   \raggedright%
   \listparindent \z@%
   \itemindent    \z@}%

\renewcommand\labelitemi{\raise0.5pt\hbox{\textbullet}}%
\renewcommand\labelitemii{\raise0.5pt\hbox{$\circ$}}%

\def\itemize{%
   \@ifnextchar[{\@itemize}{\@itemize[$\bullet$]}}

\def\@itemize[#1]{\par%
     \ifnum \@itemdepth >3 \@toodeep\else
     \advance\@itemdepth \@ne
     \edef\@itemctr{item\romannumeral\the\@itemdepth}
     \list{\csname label\@itemctr\endcsname}{%
       \itemargs
       \setlength{\leftmargin}{\csname leftmargin\romannumeral\the\@itemdepth\endcsname}
       \settowidth\labelwidth{#1}
       \addtolength{\leftmargin}{\labelwidth}
       \addtolength{\leftmargin}{\labelsep}
       \def\makelabel##1{\hss \llap{##1}}}%
     \fi
   }
\let\enditemize\endlist

%% ordered lists
\def\enumargs{%
   \leftmargini0.5cm%
   \leftmarginii0.42em%
   \ifnum\@enumdepth=3\topsep0pt\else\ifnum\@enumdepth=2\topsep0pt\else\topsep 1pt\fi\fi%
   \partopsep     \z@%
   \itemsep       \z@%
   \parsep        \z@%
   \labelsep      0.59em%
   \rightmargin   \z@%
   \raggedright%   
   \listparindent \parindent%
   \itemindent    \z@}%

\def\enumerate{%
    \@ifnextchar[{\@numerate}{\@numerate[0.]}}

\def\@numerate[#1]{\par%
     \ifnum \@enumdepth >3 \@toodeep\else
     \advance\@enumdepth \@ne
     \edef\@enumctr{enum\romannumeral\the\@enumdepth}
     \list{\csname label\@enumctr\endcsname}{%
       \enumargs%
       \setlength{\leftmargin}{\csname leftmargin\romannumeral\the\@enumdepth\endcsname}
       \usecounter{\@enumctr}
       \settowidth\labelwidth{#1}
       \addtolength{\leftmargin}{\labelwidth}
       \addtolength{\leftmargin}{\labelsep}
       \def\makelabel##1{\hss\llap{##1}}}%
     \fi
   }
\let\endenumerate\endlist


%% figure and table captions
\RequirePackage{caption}
\captionsetup[figure]{labelfont={it}, labelformat={default}, labelsep=space, name={Fig.}, justification=raggedright, skip=8pt}
\captionsetup[table]{labelfont={it}, labelformat={default}, labelsep=space, name={Tab.}, justification=raggedright, skip=4pt}
\DeclareCaptionFormat{custom}{\textit{#1#2#3}}\captionsetup{format=custom}


%% footnotes
\makeatletter
\renewcommand\@makefntext[1]{%
\leftskip=0.9em\hskip-0.8em\hb@xt@0.45em{\hss\@textsuperscript{\normalfont\@thefnmark}} \cerna #1}%
\makeatother


%% bibliography
\newlength{\bibitemsep}\setlength{\bibitemsep}{.2\baselineskip plus .05\baselineskip minus .05\baselineskip}
\newlength{\bibparskip}\setlength{\bibparskip}{0pt}
\let\oldthebibliography\thebibliography
\renewcommand\thebibliography[1]{%
  \oldthebibliography{#1}%
  \setlength{\parskip}{\bibitemsep}%
  \setlength{\itemsep}{\bibparskip}% 
  \setlength{\labelsep}{0.5\biblabelsep}
}
% bibitem numbers flushed left
\makeatletter
\renewcommand{\@biblabel}[1]{[#1]\hfill}
\makeatother


%% bibliography (with bibtex)
%\RequirePackage[square,sort,comma,numbers]{natbib}[2010/09/13]
%\setlength{\bibsep}{2pt}


%% bibliography (with biblatex)
\RequirePackage[autostyle]{csquotes}
\RequirePackage[backend=biber, style=ext-numeric, sorting=none, %
% ext-numeric, iso-numeric
% bibstyle=mybooknumeric, citestyle=numeric
% VK notes: changed from 10 to 4 authors
maxnames=4, giveninits=true, innamebeforetitle=true, %
urldate=iso, date=iso, seconds=true]{biblatex}

% bibitem numbers flushed left
\defbibenvironment{bibliography}
  {\list
     {\printtext[labelnumberwidth]{%
        \printfield{labelprefix}%
        \printfield{labelnumber}}}
     {\setlength{\labelwidth}{\labelnumberwidth}%
      \setlength{\leftmargin}{\labelwidth}%
      \setlength{\labelsep}{0.5\biblabelsep}%
      \addtolength{\leftmargin}{\labelsep}%
      \setlength{\itemsep}{\bibitemsep}%
      \setlength{\parsep}{\bibparsep}}%
      \renewcommand*{\makelabel}[1]{##1}}
  {\endlist}
  {\item}
  
% first author Family, Given, others Given Family
% default -> author, editor, translator, ...
% older: last-first, newer: given-family
\DeclareNameAlias{default}{family-given/given-family}

% suppress space between initials, there has to be space between them in bib file
\renewrobustcmd*{\bibinitdelim}{}  

% british english (incl. comma before and)
\DefineBibliographyExtras{british}{\stdpunctuation}  

% no comma before and in a list of authors
\DefineBibliographyExtras{english}{\let\finalandcomma=\empty}

% UPPERCASE for names % \textsc
\renewcommand{\mkbibnamegiven}[1]{\MakeUppercase{#1}}  
\renewcommand{\mkbibnamefamily}[1]{\MakeUppercase{#1}}
\renewcommand{\mkbibnameprefix}[1]{\MakeUppercase{#1}}
\renewcommand{\mkbibnamesuffix}[1]{\MakeUppercase{#1}}

% title without quotation marks
\DeclareFieldFormat[article,inproceedings,incollection]{title}{#1}

% remove 'in' before journal title in the article entry
\renewbibmacro{in:}{\ifentrytype{article}{}{\printtext{\bibstring{in}\intitlepunct}}}  

% volume in bold face
\DeclareFieldFormat[article,incollection]{volume}{\textbf{#1}}

% remove pp. before the page range
%\DeclareFieldFormat[article]{pages}{#1}  

% order of fields: year, vol(number), page--page
\renewbibmacro*{volume+number+eid}{%
  \setunit*{\addcomma\space}% adddot
	\usebibmacro{date}%
  \setunit*{\addcomma\space}%
  \printfield{volume}%
	\iffieldundef{number}{}{\printtext[parens]{\printfield{number}}}%
  \setunit*{\addcomma\space}%
  \printfield{eid}%
  \setunit*{\adddot\space}
  \iffieldundef{urldate}{}{\addspace\printfield{urldate}\adddot}
}
% if issue is provided instead of number
\renewbibmacro*{issue+date}{%
  \setunit{\unspace}%
  \iffieldundef{issue}{}{\printtext[parens]{\printfield{issue}}}%
}

% editor: Name, ed.
\DeclareFieldFormat[inproceedings,incollection]{editortype}{\addcomma\addspace #1}
\DeclareDelimFormat[inproceedings,incollection]{editortypedelim}{\addspace}

\DefineBibliographyStrings{english}{byeditor={ed\adddot}}
%,byeditor={eds\adddot}}

%\renewbibmacro*{byeditor+others}{%
%  \ifnameundef{editor}
%    {}
%    {%\setunit{\addspace}%
%     \printnames[byeditor]{editor}%
%     \setunit{\addcomma\addspace}%
%     \usebibmacro{byeditor+othersstrg}%
%     \clearname{editor}%
%     \newunit}%
%  \usebibmacro{byeditorx}%
%  \usebibmacro{bytranslator+others}}
\renewbibmacro*{byeditor}{%
  \ifnameundef{editor}
    {}
    {\printnames[byeditor]{editor}%
     \setunit{\addcomma\addspace}%
     \usebibmacro{bytypestrg}{editor}{editor}%
     \newunit}%
  \usebibmacro{byeditorx}}


% edition as: 3^{rd} ed.
\makeatletter
\DefineBibliographyExtras{english}{%
  \protected\def\mkbibordinal#1{%
    \begingroup
    \@tempcnta0#1\relax\number\@tempcnta
    \@whilenum\@tempcnta>100\do{\advance\@tempcnta-100\relax}%
    \ifnum\@tempcnta>20
      \@whilenum\@tempcnta>9\do{\advance\@tempcnta-10\relax}%
    \fi
    \textsuperscript{\ifcase\@tempcnta th\or st\or nd\or rd\else th\fi}%
    \endgroup}%
}
\makeatother

% identifiers: uppercase
\DeclareFieldFormat{isbn}{\mkbibacro{\MakeUppercase{ISBN}}\space #1}
\DeclareFieldFormat{issn}{\mkbibacro{\MakeUppercase{ISSN}}\space #1}
\DeclareFieldFormat{doi}{\mkbibacro{\MakeUppercase{DOI}}\space #1}
%\DeclareFieldFormat{url}{\mkbibacro{\MakeUppercase{URL}}\space #1}

% publisher+location+date [book]?
\renewbibmacro*{publisher+location+date}{%
  \printlist{location}%
  \iflistundef{publisher}{\setunit*{\addcomma\space}}{\setunit*{\addcolon\space}}%
  \printlist{publisher}%
  \setunit*{\addcomma\space}%
  \usebibmacro{date}%
  \setunit*{\addcomma\space}%
  \iffieldundef{urldate}{}{\addspace\printfield{urldate}\adddot}%
  \newunit}

% url format
\DeclareFieldFormat{url}{Available from \addspace\url{#1}\nopunct}
\DefineBibliographyStrings{english}{urlseen = {viewed}}
\DeclareFieldFormat*{urldate}{}
\DeclareFieldFormat{urldate}{\mkbibbrackets{\bibstring{urlseen}\addspace #1}}

\renewbibmacro*{doi+eprint+url}{%
  \iftoggle{bbx:doi}
    {\printfield{doi}}
    {}%
  \newunit\newblock
  \iftoggle{bbx:eprint}
    {\usebibmacro{eprint}}
    {}%
  \newunit\newblock
  \iftoggle{bbx:url}
    {\usebibmacro{url}}
    {}}


\newbibmacro*{medium-type}{%
  \iffieldundef{howpublished}
    {\ifboolexpr{
        not test {\iffieldundef{urlyear}}
        and (   test {\iftoggle{bbx:url}}
             or test {\ifentrytype{online}})
      }{\printtext[brackets]{online}}%
        {}}% Don't print anything
    {\ifboolexpr{
        test {\iffieldequalstr{howpublished}{online}}
        and not test {\iftoggle{bbx:url}}
        and not test {\ifentrytype{online}}
      }
        {}% Don't print 'howpublished' field
        {\printtext[brackets]{\printfield{howpublished}}}}%
}

\renewbibmacro*{journal+issuetitle}{%
  \usebibmacro{journal}%
  \setunit{\addspace}%
  \usebibmacro{medium-type}% new: add [online]
  \setunit*{\addspace}%
  \iffieldundef{series}
    {}
    {\newunit
     \printfield{series}%
     \setunit{\addspace}}%
  \usebibmacro{volume+number+eid}%
  \setunit{\addspace}%
  \usebibmacro{issue+date}%
  \setunit{\addcolon\space}%
  \usebibmacro{issue}%
  \newunit}

\renewbibmacro*{booktitle}{%
  \ifboolexpr{
    test {\iffieldundef{booktitle}}
    and
    test {\iffieldundef{booksubtitle}}
  }
    {}
    {\printtext[booktitle]{%
       \printfield[titlecase]{booktitle}%
       \setunit{\subtitlepunct}%
       \printfield[titlecase]{booksubtitle}}%
  \setunit{\addspace}%
  \usebibmacro{medium-type}% new: add [online]
     \newunit}%
  \printfield{booktitleaddon}}

\newbibmacro*{identifier}{%
  \iftoggle{bbx:isbn}
    {\printfield{isan}%
     \newunit
     \printfield{isbn}%
     \newunit
     \printfield{ismn}%
     \newunit
     \printfield{isrn}%
     \newunit
     \printfield{issn}%
     \newunit
     \printfield{iswc}%
     \newunit}
    {}%
}

% bibliography drivers
% source: standard.bbx, biblatex-iso690 (https://github.com/michal-h21/biblatex-iso690)
% but changed a bit :)
\DeclareBibliographyDriver{book}{%
  \usebibmacro{bibindex}%
  \usebibmacro{begentry}%
  \usebibmacro{author/editor+others/translator+others}%
  \setunit{\printdelim{nametitledelim}}\newblock
  \usebibmacro{maintitle+title}%
  \setunit{\addspace}%
  \iflistundef{language}{}{\printtext[parens]{in \printlist{language}}}%
  \setunit{\addspace}%
  \usebibmacro{medium-type}% new: add [online]
  \newunit\newblock
  \printfield{edition}%
  \newunit\newblock
  \usebibmacro{byauthor}%
  \newunit\newblock
  \usebibmacro{byeditor+others}%
  \newunit
  \iffieldundef{maintitle}{\printfield{volume}\printfield{part}}{}%
  \newunit
  \printfield{volumes}%
  \newunit\newblock
  \usebibmacro{series+number}%
  \newunit\newblock
  \printfield{note}%
  \newunit\newblock
  \usebibmacro{publisher+location+date}%
  \setunit{\addspace}%
  \usebibmacro{urldate}% new: add [viewed yyyy-mm-dd]
  \newunit\newblock
  \usebibmacro{identifier}% new: isbn
  \newunit\newblock
  \usebibmacro{doi+eprint+url}%
  \newunit\newblock
  \printfield{note}%
  \newunit\newblock
  \setunit{\bibpagerefpunct}\newblock
  \usebibmacro{pageref}%
  \usebibmacro{finentry}}


\DeclareBibliographyDriver{article}{%
  \usebibmacro{bibindex}%
  \usebibmacro{begentry}%
  \usebibmacro{author/translator+others}%
  \setunit{\printdelim{nametitledelim}}\newblock
  \usebibmacro{title}%
  \newunit
  \printlist{language}%
  \newunit\newblock
  \usebibmacro{byauthor}%
  \newunit\newblock
  \usebibmacro{bytranslator+others}%
  \newunit\newblock
  \printfield{version}%
  \newunit\newblock
  \usebibmacro{in:}%
  \usebibmacro{journal+issuetitle}% 
  \newunit
  \usebibmacro{byeditor+others}%
  \newunit
  \usebibmacro{note+pages}%
  \setunit{\addspace}%
  \usebibmacro{urldate}% new: add [viewed yyyy-mm-dd]
  \newunit\newblock
  \iftoggle{bbx:isbn}
    {\printfield{issn}}
    {}%
  \newunit\newblock
  \usebibmacro{doi+eprint+url}%
  \newunit\newblock
  \usebibmacro{addendum+pubstate}%
  \setunit{\bibpagerefpunct}\newblock
  \usebibmacro{pageref}%
  \newunit\newblock
  \iftoggle{bbx:related}
    {\usebibmacro{related:init}%
     \usebibmacro{related}}
    {}%
  \usebibmacro{finentry}}


 \DeclareBibliographyDriver{inproceedings}{%
  \usebibmacro{bibindex}%
  \usebibmacro{begentry}%
  \usebibmacro{author/translator+others}%
  \setunit{\printdelim{nametitledelim}}\newblock
  \usebibmacro{title}%
  \newunit
  \printlist{language}%
  \newunit\newblock
  \usebibmacro{byauthor}%
  \newunit\newblock
  \usebibmacro{in:}%
  \usebibmacro{byeditor}%
  \newunit\newblock
  \usebibmacro{maintitle+booktitle}%
  \newunit\newblock
  \usebibmacro{event+venue+date}%
  \newunit\newblock
  \iffieldundef{maintitle}
    {\printfield{volume}%
     \printfield{part}}
    {}%
  \newunit
  \printfield{volumes}%
  \newunit\newblock
  \usebibmacro{series+number}%
  \newunit\newblock
  \printfield{note}%
  \newunit\newblock
  \printlist{organization}%
  \newunit
  \usebibmacro{publisher+location+date}%
  \newunit\newblock
  \usebibmacro{chapter+pages}%
  \setunit{\addspace}%
  \usebibmacro{urldate}% new: add [viewed yyyy-mm-dd]
  \newunit\newblock
  \iftoggle{bbx:isbn}
    {\printfield{isbn}}
    {}%
  \newunit\newblock
  \usebibmacro{doi+eprint+url}%
  \newunit\newblock
  \usebibmacro{addendum+pubstate}%
  \setunit{\bibpagerefpunct}\newblock
  \usebibmacro{pageref}%
  \newunit\newblock
  \iftoggle{bbx:related}
    {\usebibmacro{related:init}%
     \usebibmacro{related}}
    {}%
  \usebibmacro{finentry}}
 
  \DeclareBibliographyDriver{misc}{%
  \usebibmacro{bibindex}%
  \usebibmacro{begentry}%
  \usebibmacro{author/editor+others/translator+others}%
  \setunit{\printdelim{nametitledelim}}\newblock
  \usebibmacro{title}%
  \setunit{\addspace}%
  \usebibmacro{medium-type}% new: add [type]
  \newunit
  \printlist{language}%
  \newunit\newblock
  \usebibmacro{byauthor}%
  \newunit\newblock
  \usebibmacro{byeditor+others}%
  %\newunit\newblock
  %\printfield{howpublished}%
  \newunit\newblock
  \printfield{type}%
  \newunit
  \printfield{version}%
  \newunit
  \printfield{note}%
  \newunit\newblock
  \usebibmacro{organization+location+date}%
  \newunit\newblock
  \usebibmacro{doi+eprint+url}%
  \newunit\newblock
  \usebibmacro{addendum+pubstate}%
  \setunit{\bibpagerefpunct}\newblock
  \usebibmacro{pageref}%
  \newunit\newblock
  \iftoggle{bbx:related}
    {\usebibmacro{related:init}%
     \usebibmacro{related}}
    {}%
  \usebibmacro{finentry}}